========
litestar
========

API Reference for the ``Litestar`` extensions module

.. note:: Private methods and attributes are not included in the API reference.

------------------------

.. automodule:: advanced_alchemy.extensions.litestar
    :imported-members:
        advanced_alchemy.utils
        advanced_alchemy.base
        advanced_alchemy.exceptions
        advanced_alchemy.filters
        advanced_alchemy.mixins
        advanced_alchemy.operations
        advanced_alchemy.repository
        advanced_alchemy.service
        advanced_alchemy.types
        advanced_alchemy.alembic.commands.AlembicCommands
        advanced_alchemy.extensions.litestar.plugins.init.plugin.SQLAlchemyPlugin
        advanced_alchemy.extensions.litestar.plugins.init.plugin.SQLAlchemySerializationPlugin
        advanced_alchemy.extensions.litestar.dto.SQLAlchemyDTO
        advanced_alchemy.extensions.litestar.dto.SQLAlchemyDTOConfig
    :members:
        AlembicAsyncConfig
        AlembicSyncConfig
        AsyncSessionConfig
        EngineConfig
        SQLAlchemyAsyncConfig
        SQLAlchemyInitPlugin
        SQLAlchemyPlugin
        SQLAlchemySerializationPlugin
        SQLAlchemySyncConfig
        SyncSessionConfig
        async_autocommit_before_send_handler
        async_autocommit_handler_maker
        async_default_before_send_handler
        async_default_handler_maker
        sync_autocommit_before_send_handler
        sync_autocommit_handler_maker
        sync_default_before_send_handler
        sync_default_handler_maker



Additional API References
-------------------------

.. toctree::
    :titlesonly:

    dto
    plugins
    cli
